
function testOneFramework(test, options) {
  test.waitUntilDone();
  
  let tabs = require("tabs");
  
  tabs.open({
    url: require("self").data.url("index.html"),
    onReady: function (tab) {
      let worker = tab.attach({
        contentScriptFile: options.frameworkFiles.map(function (f) require("self").data.url(f)),
        contentScript: options.contentScript,
        onMessage: function (data) {
          test.assertEqual('ready', data);
          let win = require("tab-browser").activeTab.linkedBrowser.contentWindow;
          options.onReady(win);
          tab.close();
          test.done();
        }
      });
    }
  });
}

exports.testRightJS = function testRightJS(test) {
  testOneFramework(test, {
    // http://cdn.rightjs.org/right-2.2.2.js
    frameworkFiles: ['right-2.2.2.js'],
    contentScript: 'new ' + function WorkerScope() {
      "body".update("<h1>Hello world</h1>");
      // Just ensure that it doesn't throw:
      "body".computedStyles();
      self.postMessage('ready');
    },
    onReady: function (win) {
      test.assertEqual("<h1>Hello world</h1>", win.document.body.innerHTML, 
                       "RightJS works");
    }
  });
}

exports.testMootools = function testMootools(test) {
  testOneFramework(test, {
    // http://mootools.net/download/get/mootools-core-1.3.2-full-nocompat.js
    frameworkFiles: ['mootools-core-1.3.2-full-nocompat.js'],
    contentScript: 'new ' + function WorkerScope() {
      window.addEvent('domready', function() {
        $(document.body).set("html", "<h1>Hello world</h1>");
        $(document.body).match("body");
        self.postMessage('ready');
      });
    },
    onReady: function (win) {
      test.assertEqual("<h1>Hello world</h1>", win.document.body.innerHTML, 
                       "Mootools works");
    }
  });
}


exports.testPrototype = function testPrototype(test) {
  testOneFramework(test, {
    // https://ajax.googleapis.com/ajax/libs/prototype/1.7.0.0/prototype.js
    frameworkFiles: ['prototype.js'],
    contentScript: 'new ' + function WorkerScope() {
      document.observe("dom:loaded", function() {
        $(document.body).update("<h1>Hello world</h1>");
        self.postMessage('ready');
      });
    },
    onReady: function (win) {
      test.assertEqual("<h1>Hello world</h1>", win.document.body.innerHTML, 
                       "Prototype works");
    }
  });
}

exports.testJQuery = function testJQuery(test) {
  testOneFramework(test, {
    // http://code.jquery.com/jquery-1.6.js
    frameworkFiles: ['jquery-1.6.js'],
    contentScript: 'new ' + function WorkerScope() {
      $(document).ready(function(){
        $('body').html("<h1>Hello world</h1>");
        self.postMessage('ready');
      });
    },
    onReady: function (win) {
      test.assertEqual("<h1>Hello world</h1>", win.document.body.innerHTML, 
                       "jQuery works");
    }
  });
}

exports.testJQueryUI = function testJQueryUI(test) {
  testOneFramework(test, {
    // http://code.jquery.com/jquery-1.6.js
    frameworkFiles: ['jqueryui/js/jquery-1.5.1.js',
                     'jqueryui/js/jquery-ui-1.8.12.custom.min.js'],
    contentScript: 'new ' + function WorkerScope() {
      $(document).ready(function(){
        var date = $('<input type="text" />');
        $("body").append(date);
        date.datepicker();
        var slider = $('<div></div>');
        $("body").append(slider);
        slider.slider({
          orientation: 'vertical',
          min: 0,
          max: 150,
          value: 50
        });
        
        self.postMessage('ready');
      });
    },
    onReady: function (win) {
      //throw "throw to give time to play manually with jquery UI";
      test.pass("jquery UI needs to be checked manually");
    }
  });
}
